OC.L10N.register(
    "core",
    {
    "Please select a file." : "Lūgums atlasīt datni.",
    "File is too big" : "Datne ir pārāk liela.",
    "The selected file is not an image." : "Atlasītā datne nav attēls.",
    "The selected file cannot be read." : "Atlasīto datni nevar nolasīt.",
    "The file was uploaded" : "Datne tika augšupielādēta",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Augšupielādētā datne pārsniedz php.ini norādīto upload_max_filesize vērtību",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Augšupielādētā datne pārsniedz MAX_FILE_SIZE vērtību, kas tika norādīta HTML veidlapā",
    "The file was only partially uploaded" : "Datne tika augšupielādēta tikai daļēji",
    "No file was uploaded" : "Netika augšupielādēta neviena datne",
    "Missing a temporary folder" : "Trūkst pagaidu mapes",
    "Could not write file to disk" : "Datni nevarēja ierakstīt diskā",
    "A PHP extension stopped the file upload" : "PHP paplašinājums apturēja datnes augšupielādi",
    "Invalid file provided" : "Norādīta nederīga datne",
    "No image or file provided" : "Nav norādīts attēls vai datne",
    "Unknown filetype" : "Nezināms datnes veids",
    "An error occurred. Please contact your admin." : "Atgadījās kļūda. Lūgums sazināties ar savu pārvaldītāju.",
    "Invalid image" : "Nederīgs attēls",
    "State token does not match" : "Neatbilst stāvokļa tekstvienība",
    "Invalid app password" : "Nederīga lietotnes parole",
    "Could not complete login" : "Nevarēja pabeigt pieteikšanos",
    "State token missing" : "Trūkst stāvokļa tekstvienības",
    "Your login token is invalid or has expired" : "Pieteikšanās pilnvara nav derīga vai ir beigusies",
    "Please use original client" : "Lūgums izmantot sākotnējo klientu",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Šis Nextcloud kopienas laidiens nav atbalstīts un pašpiegādes paziņojumi ir ierobežoti.",
    "Login" : "Pieteikties",
    "Unsupported email length (>255)" : "Neatbalstīts e-pasta adreses garums (>255)",
    "Password reset is disabled" : "Paroles atiestatīšana ir atspējota",
    "Could not reset password because the token is expired" : "Nevarēja atiestatīt paroli, jo ir beidzies tekstvienības derīgums",
    "Could not reset password because the token is invalid" : "Nevarēja atiestatīt paroli, jo tekstvienība ir nederīga",
    "Password is too long. Maximum allowed length is 469 characters." : "Parole ir pārāk gara. Lielākais atļautais garums ir 469 rakstzīmes.",
    "%s password reset" : "%s paroles atiestatīšana",
    "Password reset" : "Parole atiestatīta",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Jānospiež zemāk esošā poga, lai atiestatītu savu paroli. Šis e-pasta ziņojums nav jāņem vērā, ja paroles atiestatīšana netika pieprasīta.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Jāklikšķina uz zemāk esošās saites, lai atiestatītu savu paroli. Šis e-pasta ziņojums nav jāņem vērā, ja paroles atiestatīšana netika pieprasīta.",
    "Reset your password" : "Atiestatīt paroli",
    "The given provider is not available" : "Norādītais nodrošinātājs nav pieejams",
    "Task not found" : "Uzdevums nav atrasts",
    "Internal error" : "Iekšēja kļūda",
    "Not found" : "Nav atrasts",
    "Bad request" : "Slikts pieprasījums",
    "Requested task type does not exist" : "Pieprasītais uzdevumu veids nepastāv",
    "Image not found" : "Attēls nav atrasts",
    "No translation provider available" : "Tulkošanas pakalpojuma sniedzējs nav pieejams",
    "Could not detect language" : "Nevarēja noteikt valodu",
    "Unable to translate" : "Nevar iztulkot",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Labošanas solis:",
    "Repair info:" : "Labošanas informācija: ",
    "Repair warning:" : "Labošanas brīdinājums:",
    "Repair error:" : "Labošanas kļūda:",
    "Nextcloud Server" : "Nextcloud serveris",
    "Some of your link shares have been removed" : "Dažas no kopīgotajām saitēm tika noņemtas",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Drošības kļūdas dēļ mums nācās noņemt dažas no kopīgotajām saitēm. Lūgums apmeklēt saiti, lai iegūtu vairāk informācijas.",
    "The account limit of this instance is reached." : "Ir sasniegts konta ierobežojums šajā serverī.",
    "Learn more ↗" : "Uzzināt vairāk ↗",
    "Preparing update" : "Sagatavo atjauninājumu",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Lūgums izmantot komandrindas atjauninātāju, jo atjaunināšana pārlūkā ir atspējota config.php.",
    "Turned on maintenance mode" : "Ieslēgts uzturēšanas režīms",
    "Turned off maintenance mode" : "Izslēgts uzturēšanas režīms",
    "Maintenance mode is kept active" : "Uzturēšanas režīms ir paturēts aktīvs",
    "Updating database schema" : "Atjaunina datu bāzes shēmu",
    "Updated database" : "Atjaunināta datubāze",
    "Update app \"%s\" from App Store" : "Atjaunināt lietotni \"%s\" no lietotņu veikala",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Nosaka, vai uz %s attiecināmā shēma var tikt atjaunināta (tas var prasīt daudz laiku atkarībā no datu bāzes izmēriem)",
    "Updated \"%1$s\" to %2$s" : "\"%1$s\" atjauninnāts uz %2$s",
    "Set log level to debug" : "Iestatīt žurnāla līmeni uz atkļūdošanu",
    "Reset log level" : "Atiestatīt žurnāla līmeni",
    "Starting code integrity check" : "Uzsākta koda integritātes pārbaude",
    "Finished code integrity check" : "Pabeigta  koda integritātes pārbaude",
    "%s (incompatible)" : "%s (nesaderīgs)",
    "The following apps have been disabled: %s" : "Šīs lietotnes tika atspējotas: %s",
    "Already up to date" : "Jau ir jaunākā",
    "Unknown" : "Nezināms",
    "LDIF address book" : "LDIF adrešu grāmata",
    "unknown text" : "nezināms teksts",
    "Hello world!" : "Sveika, pasaule!",
    "sunny" : "saulains",
    "Hello {name}, the weather is {weather}" : "Sveiciens, {name}, laikapstākļi ir {weather}",
    "Hello {name}" : "Sveiciens, {name}",
    "new" : "jauns",
    "_download %n file_::_download %n files_" : ["lejupielādēt %n datņu","lejupielādēt %n datni","lejupielādēt %n datnes"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Notiek atjaunināšana, šīs lapas pamešana dažās vidēs var pārtraukt to.",
    "Update to {version}" : "Atjaunināt uz {version}",
    "An error occurred." : "Atgadījās kļūda.",
    "Please reload the page." : "Lūgums pārlādēt lapu.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Atjaunināšana bija nesekmīga. Vairāk informācijas par šo sarežģījumu ir skatāma <a href=\"{url}\">mūsu foruma ierakstā</a> .",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Atjaunināšana bija nesekmība. Lūgums ziņot par šo nepilnību <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud kopienai</a>.",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Atjaunināšana bija veiksmīga. Notiks pārvirzīšana uz {productName} pēc %n sekundēm.","Atjaunināšana bija veiksmīga. Notiks pārvirzīšana uz {productName} pēc %n sekundes.","Atjaunināšana bija sekmīga. Pēc %nsekundēm notiks pārvirzīšana uz {productName}."],
    "Applications menu" : "Lietotņu izvēlne",
    "Apps" : "Lietotnes",
    "More apps" : "Vairāk lietotņu",
    "_{count} notification_::_{count} notifications_" : ["{count} paziņojumu","{count}paziņojums","{count}paziņojumi"],
    "No" : "Nē",
    "Yes" : "Jā",
    "Failed to add the public link to your Nextcloud" : "Neizdevās pievienot publisku saiti Tavam Nextcloud",
    "Please copy the link manually:" : "Lūgums pašrocīgi ievietot saiti starpliktuvē:",
    "Pick start date" : "Izvēlēties sākuma datumu",
    "Pick end date" : "Izvēlēties beigu datumu",
    "Search in date range" : "Meklēt laika posmā",
    "Search in current app" : "Meklēt pašreizējā lietotnē",
    "Clear search" : "Notīrīt meklēšanu",
    "Search everywhere" : "Meklēt visur",
    "Searching …" : "Meklē...",
    "Start typing to search" : "Sākt rakstīt, lai meklētu",
    "No matching results" : "Nav atbilstoša iznākuma",
    "Today" : "Šodien",
    "Unified search" : "Apvienotā meklēšana",
    "Search apps, files, tags, messages" : "Meklēt lietotnes, datnes, birkas, ziņojumus",
    "Places" : "Vietas",
    "Date" : "Datums",
    "Search people" : "Meklēt cilvēkus",
    "People" : "Cilvēki",
    "Results" : "Rezultāti",
    "Load more results" : "Ielādēt vairāk iznākumu",
    "Search in" : "Meklēt",
    "Log in" : "Pieteikties",
    "Logging in …" : "Notiek pieteikšanās …",
    "Log in to {productName}" : "Pieteikties {productName}",
    "Wrong login or password." : "Nepareizs lietotājvārds vai parole.",
    "This account is disabled" : "Šis konts ir atspējots",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Mēs esam noteikuši vairākus nederīgus pieteikšanās mēģinājumus no šīs IP adreses, tādējādi nākamā pieteikšanās ir ierobežota līdz 30 sekundēm.",
    "Account name or email" : "Konta nosaukums vai e-pasta adrese",
    "Account name" : "Konta nosaukums",
    "Server side authentication failed!" : "Servera autentifikācija neizdevās!",
    "Please contact your administrator." : "Lūgums sazināties ar savu pārvaldītāju.",
    "Session error" : "Sesijas kļūda",
    "It appears your session token has expired, please refresh the page and try again." : "Izskatās, ka sesijas pilnvarai ir beidzies derīgums, lūgums atsvaidzināt lapu un mēģināt vēlreiz.",
    "An internal error occurred." : "Atgadījās iekšēja kļūda.",
    "Please try again or contact your administrator." : "Lūgums mēģināt vēlreiz vai sazināties ar savu pārvaldītāju.",
    "Password" : "Parole",
    "Log in with a device" : "Pieteikties ar ierīci",
    "Login or email" : "Lietotājvārds vai e-pasta adrese",
    "Your account is not setup for passwordless login." : "Konts nav iestatīts, lai pieteiktos bez paroles.",
    "Your connection is not secure" : "Savienojums nav drošs",
    "Passwordless authentication is only available over a secure connection." : "Autentifikācija bez paroles ir pieejama tikai ar drošu savienojumu.",
    "Browser not supported" : "Pārlūks nav atbalstīts",
    "Passwordless authentication is not supported in your browser." : "Pārlūks nenodrošina autentificēšanos bez paroles.",
    "Reset password" : "Atiestatīt paroli",
    "Back to login" : "Atpakaļ uz pieteikšanos",
    "Couldn't send reset email. Please contact your administrator." : "Nevarēja nosūtīt atiestatīšanas e-pasta ziņojumu. Lūgums sazināties ar savu pārvaldītāju.",
    "Password cannot be changed. Please contact your administrator." : "Parole nav nomaināma. Lūgums sazināties ar savu pārvaldītāju.",
    "New password" : "Jauna parole",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Tavas datnes ir šifrētas. Pēc paroles atiestatīšanas nebūs iespējams atgūt datus. Ja nav zināms, kā rīkoties, lūgums pirms turpināšanas sazināties ar pārvaldītāju. Vai tiešām turpināt?",
    "I know what I'm doing" : "Es zinu ko es daru",
    "Resetting password" : "Atiestata paroli",
    "Schedule work & meetings, synced with all your devices." : "Ieplāno darbu un sapulces, kas sinhronizētas ar visās izmantotajās ierīcēs.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Turiet savus kolēģus un draugus vienuviet, neizpludinot viņu privāto informāciju.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Vienkāršā e-pasta lietotne labi apvienota ar Datnēm, Kontaktiem un Kalendāru.",
    "Recommended apps" : "Ieteiktās lietotnes",
    "Loading apps …" : "Notiek lietotņu ielāde ...",
    "App download or installation failed" : "Lietotnes lejupielāde vai uzstādīšana neizdevās",
    "Cannot install this app" : "Nevarēja uzstādīt šo lietotni",
    "Skip" : "Izlaist",
    "Installing apps …" : "Notiek lietotņu instalēšana ...",
    "Settings menu" : "Iestatījumu izvēlne",
    "Loading your contacts …" : "Notiek kontaktpersonu ielāde...",
    "Looking for {term} …" : "Meklē {term} …",
    "Search contacts …" : "Meklēt kontaktpersonu",
    "Could not load your contacts" : "Nevarēja ielādēt visas kontaktpersonas",
    "No contacts found" : "Nav atrasta ne viena kontaktpersona",
    "Install the Contacts app" : "Jāuzstāda Kontaktpersonu lietotne",
    "Search" : "Meklēt",
    "Forgot password?" : "Aizmirsta parole?",
    "Back" : "Atpakaļ",
    "Security warning" : "Drošības brīdinājums",
    "Storage & database" : "Krātuve & datubāze",
    "Data folder" : "Datu mape",
    "Install and activate additional PHP modules to choose other database types." : "Jāuzstāda un jāaktivē papildu PHP moduļi, lai izvēlētos citus datubāžu veidus.",
    "For more details check out the documentation." : "Vairāk informācijas ir meklējama dokumentācijā.",
    "Performance warning" : "Veiktspējas brīdinājums",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ja izmanto klientus datņu sinhronizēšanai, ir ļoti ieteicams neizmantot SQLite.",
    "Database user" : "Datubāzes lietotājs",
    "Database password" : "Datubāzes parole",
    "Database name" : "Datubāzes nosaukums",
    "Database tablespace" : "Datubāzes tabulas telpa",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Lūgums norādītt porta numuru kopā ar resursdatora nosaukumu (piemēram, localhost:5432).",
    "Database host" : "Datubāzes serveris",
    "Need help?" : "Vajadzīga palīdzība?",
    "See the documentation" : "Skatiet dokumentāciju",
    "Choose" : "Izvēlēties",
    "Copy to {target}" : "Kopēt uz {target}",
    "Copy" : "Kopēt",
    "Move to {target}" : "Pārvietot uz {target}",
    "Move" : "Pārvietot",
    "OK" : "Labi",
    "read-only" : "tikai-skatīt",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} datnes konflikts","{count} datnes konflikts","{count} datņu konflikti"],
    "One file conflict" : "Vienas datnes konflikts",
    "New Files" : "Jaunas datnes",
    "Already existing files" : "Jau esošas datnes",
    "Which files do you want to keep?" : "Kuras datnes vēlies paturēt?",
    "If you select both versions, the copied file will have a number added to its name." : "Ja izvēlēsies paturēt abas versijas, kopētās datnes nosaukumam tiks pievienots skaitlis.",
    "Cancel" : "Atcelt",
    "Continue" : "Turpināt",
    "(all selected)" : "(visas atlasītās)",
    "({count} selected)" : "({count} iezīmēti)",
    "Error loading file exists template" : "Kļūda esošas datnes veidnes ielādēšanā",
    "Saving …" : "Saglabā ...",
    "seconds ago" : "pirms vairākām sekundēm",
    "Connection to server lost" : "Zaudēts savienojums ar serveri",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problēma ielādējot lapu, pārlādēšana pēc %n sekundēm","Problēma ielādējot lapu, pārlādēšana pēc %n sekundēm","Problēma ielādējot lapu, pārlādēšana pēc %n sekundēm"],
    "Add to a project" : "Pievienot projektam",
    "Show details" : "Rādīt informāciju",
    "Hide details" : "Paslēpt informāciju",
    "Rename project" : "Pārdēvēt projektu",
    "Failed to rename the project" : "Neizdevās pārdēvēt projektu",
    "Failed to create a project" : "Neizdevās izveidot projektu",
    "Failed to add the item to the project" : "Neizdevās pievienot vienumu projektam",
    "Connect items to a project to make them easier to find" : "Savienojiet vienumus ar projektu, lai tos būtu vieglāk atrast",
    "New in" : "Jauns",
    "View changelog" : "Skatīt izmaiņu sarakstu",
    "No action available" : "Nav pieejamu darbību",
    "Error fetching contact actions" : "Kļūda rodot kontaktpersonām piemērojamās darbības",
    "Personal" : "Personīgi",
    "Accounts" : "Konti",
    "Admin" : "Pārvaldītājs",
    "Help" : "Palīdzība",
    "Access forbidden" : "Piekļuve ir liegta",
    "Page not found" : "Lapa nav atrasta",
    "Error" : "Kļūda",
    "Internal Server Error" : "Iekšēja servera kļūda",
    "The server was unable to complete your request." : "Serveris nevarēja izpildīt tavu pieprasījumu.",
    "More details can be found in the server log." : "Vairāk informācijas var atrast servera žurnālā.",
    "For more details see the documentation ↗." : "Vairāk informācijas var atrast dokumentācijā ↗.",
    "Technical details" : "Tehniskā informācija",
    "Remote Address: %s" : "Attālā adrese: %s",
    "Request ID: %s" : "Pieprasījuma ID: %s",
    "Type: %s" : "Veids: %s",
    "Code: %s" : "Kods: %s",
    "Message: %s" : "Ziņojums: %s",
    "File: %s" : "Datne: %s",
    "Line: %s" : "Līnija: %s",
    "Trace" : "Izsekot",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Šīs lietotnes pareizai darbībai ir nepieciešams JavaScript. Lūgums {linkstart}ieslēgt JavasScript{linkend} un pārlādēt lapu.",
    "Connect to your account" : "Savienoties ar savu kontu",
    "Please log in before granting %1$s access to your %2$s account." : "Lūgums pieteikties pirms piekļuves piešķiršanas %1$s savam %2$s kontam.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ja nemēģini iestatīt jaunu ierīci vai lietotni, kāds mēģina apmānīt Tevi, lai Tu piešķirtu piekļuvi saviem datiem. Tādā gadījumā neturpini, un tā vietā sazinies ar savas sistēmas pārvaldītāju!",
    "App password" : "Lietotnes parole",
    "Grant access" : "Piešķirt piekļuvi",
    "Alternative log in using app password" : "Tā vietā pieteikties ar lietotnes paroli",
    "Account access" : "Piekļuve kontam",
    "Currently logged in as %1$s (%2$s)." : "Pašreiz pieteicies kā %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Tu grasies piešķirt %1$s piekļuvi savam %2$s kontam.",
    "Account connected" : "Konts sasaistīts",
    "Your client should now be connected!" : "Klientam tagad vajadzētu būt sasaistītam.",
    "You can close this window." : "Šo logu var aizvērt.",
    "Previous" : "Iepriekšējā",
    "This share is password-protected" : "Šis kopīgojums ir aizsargāts ar paroli",
    "Email address" : "E-pasta adrese",
    "Password sent!" : "Parole ir nosūtīta.",
    "Two-factor authentication" : "Divpakāpju pieteikšanās",
    "Use backup code" : "Izmantot rezerves kodu",
    "Cancel login" : "Atcelt pieteikšanos",
    "Error while validating your second factor" : "Kļūda otras pakāpes pārbaudīšanas laikā",
    "Access through untrusted domain" : "Piekļūt caur neuzticamu domēnu",
    "App update required" : "Nepieciešama lietotnes atjaunināšana",
    "%1$s will be updated to version %2$s" : "%1$s tiks atjaunināta uz versiju %2$s",
    "These incompatible apps will be disabled:" : "Šīs nesaderīgās lietotnes tiks atspējotas:",
    "The theme %s has been disabled." : "Tēma %s ir atspējota.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Pirms turpināšanas lūgums pārliecināties, ka datubāzei un config un data mapēm ir izveidotas rezerves kopijas.",
    "Start update" : "Sākt atjaunināšanu",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Lai izvairītos no noildzēm lielākās instalācijās, tā vietā uzstādīšanas mapē var izpildīt šo komandu:",
    "Detailed logs" : "Detalizēti žurnāli",
    "Update needed" : "Nepieciešama atjaunināšana",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Es zinu, ka, ja es turpināšu atjaunināšanu tīmekļa saskarnē, pastāv iespēja, ka pieprasījumam var iestāties noildze un var rasties datu zudums, bet man ir rezerves kopija, un es zinu kā neveiksmes gadījumā atjaunot savu serveri.",
    "Upgrade via web on my own risk" : "Atjaunināt caur tīmekļa atjauninātāju uz mana paša risku.",
    "Maintenance mode" : "Uzturēšanas režīms",
    "This %s instance is currently in maintenance mode, which may take a while." : "Šis %s serveris pašlaik darbojas uzturēšanas režīmā, tas var ilgt kādu laiku.",
    "This page will refresh itself when the instance is available again." : "Šī lapa atsvaidzināsies, kad Nextcloud būs atkal pieejams.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Jāsazinās ar sistēmas pārvaldītāju, ja šis ziņojums nepazūd vai parādījās negaidīti",
    "No temporary profile picture available, try again" : "Nav pieejams profila pagaidu attēls, jāmēģina vēlreiz",
    "No crop data provided" : "Nav norādīti apgriešanas dati",
    "No valid crop data provided" : "Nav norādīti derīgi apgriešanas dati",
    "Crop is not square" : "Griezums nav kvadrāts",
    "Error occurred while checking server setup" : "Servera pārbaudīšanas laikā atgadījās kļūda",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Vairāk informācijas ir skatāma {linkstart}dokumentācijā ↗{linkend}.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Tērzēšana, videozvani, ekrāna kopīgošana, tiešsaistes sapulces un tīmekļa apspriedes - pārlūkā un viedierīču lietotnēs.",
    "You have not added any info yet" : "Vēl nav pievienota nekāda informācija",
    "{user} has not added any info yet" : "{user} vēl nav pievienojis nekādu informāciju ",
    "Edit Profile" : "Labot profilu",
    "Very weak password" : "Ļoti vāja parole",
    "Weak password" : "Vāja parole",
    "So-so password" : "Viduvēja parole",
    "Good password" : "Laba parole",
    "Strong password" : "Spēcīga parole",
    "Non-existing tag #{tag}" : "Neesoša birka #{tag}",
    "Restricted" : "Ierobežota",
    "Invisible" : "Neredzama",
    "Delete" : "Izdzēst",
    "Rename" : "Pārdēvēt",
    "Collaborative tags" : "Sadarbības birkas",
    "No tags found" : "Netika atrasta neviena birka",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Iespējams, ka datu mape un datnes ir pieejamas no interneta, jo .htaccess datne nedarbojas.",
    "Show password" : "Rādīt paroli",
    "Toggle password visibility" : "Pārslēgt paroles redzamību",
    "Configure the database" : "Konfigurēt datubāzi",
    "Only %s is available." : "Tikai %s ir pieejams.",
    "Database account" : "Datubāzes konts"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
